@@ -16,9 +16,8 @@
 #' read and calc functions should be searched for
 #' @param globalenv Boolean deciding whether sources/calculations in the global
 #' environment should be included or not
-#' @param enablecache Boolean deciding whether data should be read from cache
-#' if data is available and the up-to-date (data will always be written to the
-#' cache regardless of this setting)
+#' @param enablecache Is deprecated and will be ignored. Please use
+#' \code{ignorecache} instead.
 #' @param verbosity an integer value describing the verbosity of the functions
 #' (2 = full information, 1 = only warnings and execution information, 0 = only
 #' warnings, -1 = no information)
@@ -38,11 +37,10 @@
 #' @param outputfolder The folder all outputs should be written to. In the
 #' default case this argument is set to NA meaning that the default folder
 #' should be used which is <mainfolder>/output
-#' @param pop_threshold Population threshold in capita which determines whether
-#' the country is put into the "important" or "dispensable" class in
-#' \code{\link{getISOlist}}. This distinction is used for different treatment
-#' of countries in notifications to set a focus on rather critical issues
-#' instead of flooding the user with information.
+#' @param pucfolder The path where portable unaggregated collection (puc) files
+#' are located. NA by default, which means <mainfolder>/puc
+#' @param tmpfolder Path to a temp folder for temporary storage of files. By default
+#' set to <mainfolder>/tmp
 #' @param nolabels vector of retrieve models (e.g. "EXAMPLE" in case of "fullEXAMPLE")
 #' which should NOT apply a replacement of known hashes with given code labels
 #' @param forcecache Argument that allows to force madrat to read data from
@@ -58,19 +56,14 @@
 #' "bzip2" or "xz" specify the type of compression.
 #' @param hash specifies the used hashing algorithm. Default is "xxhash32" and
 #' all algorithms supported by \code{\link[digest]{digest}} can be used.
-#' @param delete_cache Boolean deciding whether a temporary cache folder (as
-#' created by retrieveInput) should be deleted after completion or not.
-#' @param diagnostics file name for additional diagnostics information (without file ending).
-#' 2 log files are written if a file name is provided (a compact version with the most
-#' relevant information and a full version with all available details).
-#' @param nocores integer number of cores to use
+#' @param diagnostics Either FALSE (default) to avoid the creation of additional
+#' log files or a file name for additional diagnostics information (without file ending).
 #' @param debug Boolean which activates a debug mode. In debug mode all calculations will
 #' be executed with try=TRUE so that calculations do not stop even if the previous calculation failed.
 #' This can be helpful to get a full picture of errors rather than only seeing the first one. In addition
 #' debug=TRUE will add the suffix "debug" to the files created to avoid there use in productive runs.
 #' Furthermore, with debug=TRUE calculations will be rerun even if a corresponding tgz file
 #' already exists.
-#' @param indentationCharacter character used for indenting the output of nested function calls
 #' @param maxLengthLogMessage in log messages evaluated arguments are printed if the resulting message
 #' is shorter than this value, otherwise arguments are shown as passed, potentially  with unevaluated variable names
 #' @param .cfgchecks boolean deciding whether the given inputs to setConfig should be checked for
@@ -78,6 +71,12 @@
 #' in regular cases)
 #' @param .verbose boolean deciding whether status information/updates should be shown or not
 #' @param .local boolean deciding whether options are only changed until the end of the current function execution
+#' OR environment for which the options should get changed.
+#' @note \code{setConfig} must only be used before the data processing is started and changes in the configuration
+#' from within a download-, read-, correct-, convert-, calc-, or full-function are not allowed! Only allowed
+#' configuration update is to add another \code{extramapping} via \code{\link{addMapping}}.
+#' Currently the use of \code{setConfig} within any of these functions will trigger a warning, which is planned
+#' to be converted into an error message in one of the next package updates!
 #' @author Jan Philipp Dietrich
 #' @seealso \code{\link{getConfig}}, \code{\link{getISOlist}}
 #' @examples
@@ -87,7 +86,7 @@
 #' @importFrom utils installed.packages
 #' @importFrom withr local_options
 #' @export
-setConfig <- function(regionmapping = NULL,
+setConfig <- function(regionmapping = NULL, # nolint
                       extramappings = NULL,
                       packages = NULL,
                       globalenv = NULL,
@@ -98,26 +97,51 @@ setConfig <- function(regionmapping = NULL,
                       cachefolder = NULL,
                       mappingfolder = NULL,
                       outputfolder = NULL,
-                      pop_threshold = NULL, # nolint
+                      pucfolder = NULL,
+                      tmpfolder = NULL,
                       nolabels = NULL,
                       forcecache = NULL,
                       ignorecache = NULL,
                       cachecompression = NULL,
                       hash = NULL,
-                      delete_cache = NULL, # nolint
                       diagnostics = NULL,
-                      nocores = NULL,
                       debug = NULL,
-                      indentationCharacter = NULL,
                       maxLengthLogMessage = NULL,
                       .cfgchecks = TRUE,
                       .verbose = TRUE,
                       .local = FALSE) {
+
+  if (isWrapperActive("wrapperChecks")) {
+    for (w in c("downloadSource", "readSource", "calcOutput", "retrieveData")) {
+      if (isWrapperActive(w)) {
+        warning("setConfig must not be used from within ", w, "!")
+        break
+      }
+    }
+  }
+  setWrapperInactive("wrapperChecks")
+
   cfg <- getConfig(raw = TRUE, verbose = .verbose)
 
+  if (is.environment(.local)) {
+    .localEnvir <- .local
+    .local <- TRUE
+  } else {
+    .localEnvir <- parent.frame()
+  }
+
   firstsetting <- TRUE
   info <- NULL
 
+  if (!is.null(regionmapping) && file.exists(regionmapping)) {
+    regionmapping <- normalizePath(regionmapping)
+  }
+
+  if (!is.null(enablecache)) {
+    warning('Argument "enablecache" is deprecated and will be ignored, use "ignorecache" instead!')
+    enablecache <- NULL
+  }
+
   if (!is.null(packages)) {
     packages <- unique(packages, fromLast = TRUE)
     if (.cfgchecks) {
@@ -135,7 +159,7 @@ setConfig <- function(regionmapping = NULL,
   for (x in args) {
     if (!is.null(get(x))) {
       value <- get(x)
-      if (x == "extramappings" && value == "") value <- NULL
+      if (x == "extramappings" && length(value) == 1 && value == "") value <- NULL
       # additional checks/modifications if input is a folder
       if (grepl("folder", x, fixed = TRUE)) {
         if (!is.na(value)) {
@@ -152,7 +176,13 @@ setConfig <- function(regionmapping = NULL,
           value <-  sub("/$", "", normalizePath(value, winslash = "/"))
         }
       }
-      if (firstsetting) info <- "Configuration update:"
+      if (firstsetting) {
+        if (.local) {
+          info <- "Local configuration update:"
+        } else {
+          info <- "Global configuration update:"
+        }
+      }
       firstsetting <- FALSE
       info <- c(info, paste0("  ", x, ": ", paste(cfg[[x]], collapse = ", "), " -> ", paste(value, collapse = ", ")))
       cfg[[x]] <- value
@@ -160,12 +190,18 @@ setConfig <- function(regionmapping = NULL,
   }
   if (.local) {
     # change options until the function calling this function exits
-    local_options(madrat_cfg = cfg, .local_envir = parent.frame())
+    local_options(madrat_cfg = cfg, .local_envir = .localEnvir)
   } else {
     options(madrat_cfg = cfg) # nolint
   }
 
-  if (!is.null(info) & .verbose) {
+  if (!is.null(info) && .verbose) {
     for (i in info) vcat(-2, i)
   }
 }
+
+#' @describeIn setConfig A wrapper for setConfig(..., .local = TRUE)
+#' @param ... Arguments forwarded to setConfig
+#' @export
+# setting .local = TRUE would only set config until localConfig ends
+localConfig <- function(...) setConfig(..., .local = parent.frame())
