@@ -1,14 +1,10 @@
-context("getMadratGraph")
-
-globalassign <- function(...) {
-  for (x in c(...)) assign(x, eval.parent(parse(text = x)), .GlobalEnv)
-}
-
 test_that("getMadratGraph works", {
   calcTest1 <- function() return(1)
   calcTest2 <- function() return(calcOutput("Test1"))
   globalassign("calcTest1", "calcTest2")
-  expect_silent(graph <- getMadratGraph(packages = "madrat", globalenv = TRUE))
+  expect_silent({
+    graph <- getMadratGraph(packages = "madrat")
+  })
   expect_setequal(graph$from_package, c("madrat", ".GlobalEnv"))
   expect_setequal(graph$to_package, c("madrat", ".GlobalEnv"))
 })
@@ -16,5 +12,3 @@ test_that("getMadratGraph works", {
 test_that("MADRaT Universe detection works", {
   expect_true("madrat" %in% installedMadratUniverse())
 })
-
-rm(list = ls(envir = .GlobalEnv), envir = .GlobalEnv)
